@@ -1021,6 +1021,35 @@ class TestNetworkElement(unittest.TestCase):
         msg = ne.offline_disconnected_update_msg
         self.assertIsNotNone(ne)
         self.assertEqual(msg.data.status, network_poller_pb2.ELEMENT_STATUS_OFFLINE)
+    
+    def test_bad_data_range_flag(self):
+        cfg = {
+            'disable_bad_data_range_error': True
+        }
+
+        ne = self._await(self.reg.set('TestNE', {'name': 'Test Element', 'site': 'My Site'}))
+        ne.cfg = cfg
+        ne.device = FakeDevice(None)
+        ne.network_element_update_msg = NetworkElementUpdate()
+        ne.network_element_update_msg.data = NetworkElement(errctx=ErrorContext())
+
+        ne_msg = NetworkElement(errctx=ErrorContext())
+        ne_msg.poller_hash = bytes('test poller hash', 'UTF-8')
+        ne_errctx = ErrorContext()
+        ne_errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.PonLink.rx_power',
+                                value=-50,
+                                metric_name='NetworkElement.PonLink.rx_power')
+        
+        #disable_bad_data_range_error = True
+        ne.set_element_status(ne_msg, ne_errctx)
+        self.assertEqual(len(ne_msg.errors), 0)
+
+        #disable_bad_data_range_error = False
+        cfg['disable_bad_data_range_error'] = False
+        ne.set_element_status(ne_msg, ne_errctx)
+        self.assertEqual(len(ne_msg.errors), 1)
+
 
     def test_suppress_offline_update_to_agent_polled_element(self):
         """STM-9828 the poller doesn't send OFFLINE updates for elements
